@@ -3,8 +3,10 @@
 from .core import QSpider, ThreadManager, ThreadTaskQueue, ThreadWorker, Task, \
     ProcessManager, ProcessTaskQueue, ProcessWorker, genqspider, SharedCounter
 from .utils import display_progress, Timer, INFO, WARN, ERROR
+from .decorators import concurrent
 
 
 __all__ = ['QSpider', 'ThreadManager', 'ThreadTaskQueue', 'ThreadWorker', 'Task',
            'ProcessManager', 'ProcessTaskQueue', 'ProcessWorker', 'genqspider',
-           'SharedCounter', 'display_progress', 'Timer', 'INFO', 'WARN', 'ERROR']
+           'SharedCounter', 'display_progress', 'Timer', 'INFO', 'WARN', 'ERROR',
+           'concurrent']
