@@ -8,15 +8,11 @@ class {0}(ThreadManager):
         self.has_result = has_result
         self.add_failed = add_failed
         self.source = [0]
-        super({0}, self).__init__(self.source, self.QTask, has_result=self.has_result, add_failed=self.add_failed)
+        super({0}, self).__init__(self.source, self.task, has_result=self.has_result, add_failed=self.add_failed)
 
-    class QTask(Task):
-        def __init__(self, task_source):
-            Task.__init__(self, task_source)
-            
-        def run(self):
-            # parse single task source
-            pass
+    def task(self, task_source):
+        # parse single task source
+        pass
 
 if __name__=="__main__":
     qspider = {0}()
